@@ -9,7 +9,7 @@
 use strict; use warnings;
 package Test::Apocalypse::OutdatedPrereqs;
 BEGIN {
-  $Test::Apocalypse::OutdatedPrereqs::VERSION = '1.000';
+  $Test::Apocalypse::OutdatedPrereqs::VERSION = '1.001';
 }
 BEGIN {
   $Test::Apocalypse::OutdatedPrereqs::AUTHORITY = 'cpan:APOCAL';
@@ -106,11 +106,8 @@ sub _load_yml {
 
 	# analyze every one of them!
 	plan tests => scalar keys %$data;
-	TODO: {
-		local $TODO = "OutdatedPrereqs";
-		foreach my $prereq ( keys %$data ) {
-			_check_cpan( $cpanplus, $prereq, $data->{ $prereq } );
-		}
+	foreach my $prereq ( keys %$data ) {
+		_check_cpan( $cpanplus, $prereq, $data->{ $prereq } );
 	}
 
 	return;
@@ -150,7 +147,10 @@ sub _check_cpan {
 		my $cpanversion = version->new( $module->version );
 
 		# check it! ( use <= instead of == so we ignore old CPAN versions )
-		cmp_ok( $cpanversion, '<=', $version, "Comparing '$prereq' to CPAN version" );
+		TODO: {
+			local $TODO = "OutdatedPrereqs";
+			cmp_ok( $cpanversion, '<=', $version, "Comparing '$prereq' to CPAN version" );
+		}
 	} else {
 		my $release = Module::CoreList->first_release( $prereq );
 		if ( defined $release ) {
@@ -169,9 +169,11 @@ sub _check_cpan {
 __END__
 =pod
 
-=for Pod::Coverage do_test
+=for :stopwords Apocalypse
 
-=for stopwords CPAN prereq prereqs backend
+=encoding utf-8
+
+=for Pod::Coverage do_test
 
 =head1 NAME
 
@@ -179,12 +181,14 @@ Test::Apocalypse::OutdatedPrereqs - Plugin to detect outdated prereqs
 
 =head1 VERSION
 
-  This document describes v1.000 of Test::Apocalypse::OutdatedPrereqs - released March 04, 2011 as part of Test-Apocalypse.
+  This document describes v1.001 of Test::Apocalypse::OutdatedPrereqs - released March 08, 2011 as part of Test-Apocalypse.
 
 =head1 DESCRIPTION
 
 This plugin detects outdated prereqs in F<META.yml> specified relative to CPAN. It uses L<CPANPLUS> as the backend.
 
+=for stopwords CPAN prereq prereqs backend
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -193,7 +197,7 @@ Please see those modules/websites for more information related to this module.
 
 =item *
 
-L<Test::Apocalypse>
+L<Test::Apocalypse|Test::Apocalypse>
 
 =back
 
@@ -210,5 +214,28 @@ the same terms as the Perl 5 programming language system itself.
 
 The full text of the license can be found in the LICENSE file included with this distribution.
 
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
 =cut
 
