@@ -9,7 +9,7 @@
 use strict; use warnings;
 package Test::Apocalypse::Pod_Spelling;
 BEGIN {
-  $Test::Apocalypse::Pod_Spelling::VERSION = '1.000';
+  $Test::Apocalypse::Pod_Spelling::VERSION = '1.001';
 }
 BEGIN {
   $Test::Apocalypse::Pod_Spelling::AUTHORITY = 'cpan:APOCAL';
@@ -65,9 +65,11 @@ sub do_test {
 __END__
 =pod
 
-=for Pod::Coverage do_test
+=for :stopwords Apocalypse
 
-=for stopwords spellchecker stopword stopwords pm
+=encoding utf-8
+
+=for Pod::Coverage do_test
 
 =head1 NAME
 
@@ -75,7 +77,7 @@ Test::Apocalypse::Pod_Spelling - Plugin for Test::Spelling
 
 =head1 VERSION
 
-  This document describes v1.000 of Test::Apocalypse::Pod_Spelling - released March 04, 2011 as part of Test-Apocalypse.
+  This document describes v1.001 of Test::Apocalypse::Pod_Spelling - released March 08, 2011 as part of Test-Apocalypse.
 
 =head1 DESCRIPTION
 
@@ -83,6 +85,8 @@ Encapsulates L<Test::Spelling> functionality. We also add each filename as a sto
 
 If you need to add stopwords, please look at L<Pod::Spell> for ways to add it to each .pm file!
 
+=for stopwords spellchecker stopword stopwords pm
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -91,7 +95,7 @@ Please see those modules/websites for more information related to this module.
 
 =item *
 
-L<Test::Apocalypse>
+L<Test::Apocalypse|Test::Apocalypse>
 
 =back
 
@@ -108,5 +112,28 @@ the same terms as the Perl 5 programming language system itself.
 
 The full text of the license can be found in the LICENSE file included with this distribution.
 
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
 =cut
 
